@@ -31,7 +31,6 @@
 
 #ifdef HAVE_KPEOPLE
 #include <KPeople/PersonsModel>
-#include <kpeople/personsmodelfeature.h>
 #include "kpeopletranslationproxy.h"
 #endif
 
@@ -62,22 +61,9 @@ KTp::ContactsModel::ContactsModel(QObject *parent)
     d->trackUnread = false;
     if (KTp::kpeopleEnabled()) {
         #ifdef HAVE_KPEOPLE
-        kDebug() << "Nepomuk is enabled, using kpeople model";
+        kDebug() << "Built with kpeople support, using kpeople model";
         KPeople::PersonsModel *personsModel = new KPeople::PersonsModel(this);
 
-        KPeople::PersonsModelFeature accountFeature;
-        QHash<QString, int> bindingMap;
-        bindingMap[QLatin1String("account")] = KPeople::PersonsModel::UserRole;
-        accountFeature.setBindingsMap(bindingMap);
-        accountFeature.setOptional(false);
-        accountFeature.setQueryPart(QLatin1String("?uri nco:hasIMAccount ?imAccount . ?imAccount nco:isAccessedBy ?accessedBy . ?accessedBy telepathy:accountIdentifier ?account . "));
-
-        personsModel->startQuery(QList<KPeople::PersonsModelFeature>() << KPeople::PersonsModelFeature::imModelFeature(KPeople::PersonsModelFeature::Mandatory)
-                                                            << accountFeature
-                                                            << KPeople::PersonsModelFeature::avatarModelFeature()
-                                                            << KPeople::PersonsModelFeature::groupsModelFeature()
-                                                            << KPeople::PersonsModelFeature::fullNameModelFeature()
-                                                            << KPeople::PersonsModelFeature::nicknameModelFeature());
         connect(personsModel, SIGNAL(modelInitialized()),
                 this, SIGNAL(modelInitialized()));
 
@@ -87,7 +73,7 @@ KTp::ContactsModel::ContactsModel(QObject *parent)
     }
     else
     {
-        kDebug() << "Nepomuk is disabled, using normal model";
+        kDebug() << "KPeople support not built-in, using normal model";
         d->source = new KTp::ContactsListModel(this);
         connect(d->source, SIGNAL(modelInitialized()),
                 this, SIGNAL(modelInitialized()));
